@@ -6,7 +6,9 @@ def socket_loader(socket_size):
     socket_wait = socket_size / 1000
     for i in range(51):
         sys.stdout.write("\r")
-        sys.stdout.write("%s%% | %s" % (int(i / 50 * 100), i * "|"))
+        sys.stdout.write("%s%% | %s" % (int(i / 50 * 100), i * "#"))
         sys.stdout.flush()
         time.sleep(socket_wait)
-    print('\n')
\ No newline at end of file
+    print('\n')
+    
+socket_loader(1000)
\ No newline at end of file
